local NShakedown = NShakedown
local revision = tonumber(("$Revision: 70161 $"):match("%d+"))
if not NShakedown.revision or revision > NShakedown.revision then
    NShakedown.revision = revision
    NShakedown.version = "r"..NShakedown.revision 
    NShakedown.date = ("$Date: 2008-04-17 01:34:57 -0400 (Thu, 17 Apr 2008) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

local Addon = NShakedown.AddonBase:new("BigWigs", "BigWigs")
if not Addon then return end
Rock("LibRockTimer-1.0"):Embed(Addon)

-- constants
local BAR_NUMBER = 5
local BAR_DURATION = { 10, 15, 20, 24, 27 }
local TIMER_BAR_FREQ = 30
local TIMER_BAR_ID = "BigWigsBarShakedown"
local TIMER_MSG_FREQ = 3
local TIMER_MSG_ID = "BigWigsMSGShakedown"
local BAR_ID = "Shakedown BigWigs %d"

-- members
Addon.testPlugin = nil
Addon.proximityPlugin = nil

function Addon:Start()
    
    -- activate the addon if necessary
    if not BigWigs:IsActive() then
        BigWigs:ToggleActive(true)
    end
    
    -- activate the test plugin
    if not self.testPlugin then
        self.testPlugin = BigWigs:GetModule("Test")
    end
    if not self.testPlugin then return end
    
    -- attempt to activate the proximity plugin
    if not self.proximityPlugin then
        self.proximityPlugin = BigWigs:GetModule("Proximity")
    end
    
    -- show a message now
    self:ShowMessage()
    
    -- show bars now
    self:ShowBar()

    --schedule repeating messages and bars
    self:AddRepeatingTimer(TIMER_BAR_ID, TIMER_BAR_FREQ, self.ShowBar, self)
    self:AddRepeatingTimer(TIMER_MSG_ID, TIMER_MSG_FREQ, self.ShowMessage, self)
    
    -- show the bar anchors
    BigWigs.cmdtable.args.Plugins.args.Bars.args.anchor.set("anchor", true)
    
    -- show the message anchor
    if not BigWigs.cmdtable.args.Plugins.args.Messages.args.anchor.disabled() then
        BigWigs.cmdtable.args.Plugins.args.Messages.set("anchor", true)
    end
    
    -- show the proximity frame
    if self.proximityPlugin then
        self.proximityPlugin:BigWigs_ShowProximity(self)
    end
end

function Addon:Stop()
    
    -- check existence
    if not BigWigs then return end
    if not self.testPlugin then return end
    
    -- kill the scheduled messages and bars
    self:RemoveTimer(TIMER_BAR_ID)
    self:RemoveTimer(TIMER_MSG_ID)
    
    -- kill each of the bars
    for i = 1, BAR_NUMBER do
        self.testPlugin:TriggerEvent("BigWigs_StopBar", self.testPlugin, string.format(BAR_ID, i))
    end
    
    -- hide the bar anchors
    BigWigs.cmdtable.args.Plugins.args.Bars.args.anchor.set("anchor", false)

    -- hide the message anchor
    BigWigs.cmdtable.args.Plugins.args.Messages.set("anchor", false)
    
    -- hide the proximity frame
    if self.proximityPlugin then
        self.proximityPlugin:BigWigs_HideProximity(self)
    end
end

-- create some bars
function Addon:ShowBar()

    if not self.testPlugin then return end

    for i = 1, BAR_NUMBER do
        self.testPlugin:Bar( string.format(BAR_ID, i), BAR_DURATION[i], "Spell_Nature_ResistNature")
    end

end

local red = {r = 1, g = 0, b = 0}
-- show a message
function Addon:ShowMessage()

    if not self.testPlugin then return end
   
    -- display a single message
    self.testPlugin:TriggerEvent("BigWigs_Message", "BigWigs Message", red, true)
    self.testPlugin:TriggerEvent("BigWigs_Message", "BigWigs Message", red, true)
    
end

-- dummy proximity check for the proximity frame to use
Addon.proximityCheck = function( unit ) 
	return false
end
Addon.db = { profile = { proximity = true } }